@@ -1,4 +1,4 @@
-import six
+from typing import Type, TypeVar, Union
 
 from hamcrest.core.base_matcher import Matcher
 from hamcrest.core.core.isequal import equal_to
@@ -7,9 +7,10 @@ __author__ = "Jon Reid"
 __copyright__ = "Copyright 2011 hamcrest.org"
 __license__ = "BSD, see License.txt"
 
-import types
+T = TypeVar("T")
 
-def wrap_matcher(x):
+
+def wrap_matcher(x: Union[Matcher[T], T]) -> Matcher[T]:
     """Wraps argument in a matcher, if necessary.
 
     :returns: the argument as-is if it is already a matcher, otherwise wrapped
@@ -21,11 +22,9 @@ def wrap_matcher(x):
     else:
         return equal_to(x)
 
-def is_matchable_type(expected_type):
+
+def is_matchable_type(expected_type: Type) -> bool:
     if isinstance(expected_type, type):
         return True
 
-    if isinstance(expected_type, six.class_types):
-        return True
-
     return False
